@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: PlaceUtils.py 8129 2007-02-16 19:42:07Z bmcage $
+# $Id:PlaceUtils.py 9912 2008-01-22 09:17:46Z acraphae $
 
 # Written by Benny Malengier
 
@@ -64,7 +64,6 @@ if 'N' == South or 'S' == North or 'E' == West or 'W' == East:
     translate_en_loc['S'] = 'S'
     translate_en_loc['E'] = 'E'
     translate_en_loc['W'] = 'W'
-    
 # end localisation part
 
 #-------------------------------------------------------------------------
@@ -75,7 +74,7 @@ if 'N' == South or 'S' == North or 'E' == West or 'W' == East:
 
 def conv_lat_lon(latitude, longitude, format="D.D4"):
     """
-    Converts given string latitude and longitude to a required format. 
+    Convert given string latitude and longitude to a required format. 
     Possible formats:
         'D.D4'    : degree notation, 4 decimals 
                     eg +12.0154 , -124.3647
@@ -176,13 +175,16 @@ def conv_lat_lon(latitude, longitude, format="D.D4"):
             val = val.replace( r'#',r'_')
             #allow to input " as ''
             val = val.replace( r"''",r'"')
+            #allow some special unicode symbols
+            val = val.replace( u'\u2033',r'"')
+            val = val.replace( u'\u2032',r"'")
             #ignore spaces
             val = val.replace(r'\s*', r'')
             # get the degrees, must be present
             if val.find(r'_') != -1:
                 l = val.split('_')
                 if len(l) != 2:
-                    error = True
+                    error = True 
                 else:
                     try: 
                         degs = int(l[0])  #degrees must be integer value
