@@ -1,7 +1,7 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2000-2006  Donald N. Allingham
+# Copyright (C) 2000-2007  Donald N. Allingham
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Verify.py 8464 2007-05-13 03:28:50Z dallingham $
+# $Id: Verify.py 10164 2008-03-02 19:40:34Z ldnp $
 
 """
-A plugin to verify the data against user-adjsted tests.
+A plugin to verify the data against user-adjusted tests.
 This is the research tool, not the low-level data ingerity check.
 """
 
@@ -31,7 +31,6 @@ This is the research tool, not the low-level data ingerity check.
 #
 #------------------------------------------------------------------------
 import os
-from gettext import gettext as _
 import cPickle
 import md5
 import Errors
@@ -42,7 +41,8 @@ import Errors
 #
 #------------------------------------------------------------------------
 import gtk
-import gtk.glade 
+from gtk import glade
+import gobject
 
 #------------------------------------------------------------------------
 #
@@ -50,12 +50,20 @@ import gtk.glade
 #
 #------------------------------------------------------------------------
 import const
-import RelLib
+import gen.lib
 import Utils
 import GrampsDisplay
 from ManagedWindow import ManagedWindow
 from BasicUtils import UpdateCallback
 from PluginUtils import Tool, register_tool
+from TransUtils import sgettext as _
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+WIKI_HELP_PAGE = 'Gramps_3.0_Wiki_Manual_-_Tools'
+WIKI_HELP_SEC = _('manual|Verify_the_Data...')
 
 #-------------------------------------------------------------------------
 #
@@ -66,7 +74,7 @@ _person_cache = {}
 _family_cache = {}
 _event_cache = {}
 
-def find_event(db,handle):
+def find_event(db, handle):
     try:
         obj = _event_cache[handle]
     except KeyError:
@@ -74,7 +82,7 @@ def find_event(db,handle):
         _event_cache[handle] = obj
     return obj
 
-def find_person(db,handle):
+def find_person(db, handle):
     try:
         obj = _person_cache[handle]
     except KeyError:
@@ -82,7 +90,7 @@ def find_person(db,handle):
         _person_cache[handle] = obj
     return obj
 
-def find_family(db,handle):
+def find_family(db, handle):
     try:
         obj = _family_cache[handle]
     except KeyError:
@@ -105,6 +113,8 @@ def get_date_from_event_handle(db,event_handle):
         return 0
     event =  find_event(db,event_handle)
     date_obj = event.get_date_object()
+    if date_obj.get_day() == 0 or date_obj.get_month() == 0:
+        return 0
     return date_obj.get_sort_value()
 
 def get_date_from_event_type(db,person,event_type):
@@ -114,14 +124,16 @@ def get_date_from_event_type(db,person,event_type):
         event = find_event(db,event_ref.ref)
         if event.get_type() == event_type:
             date_obj = event.get_date_object()
+            if date_obj.get_day() == 0 or date_obj.get_month() == 0:
+                return 0
             return date_obj.get_sort_value()
     return 0
 
 def get_bapt_date(db,person):
-    return get_date_from_event_type(db,person,RelLib.EventType.BAPTISM)
+    return get_date_from_event_type(db,person,gen.lib.EventType.BAPTISM)
 
 def get_bury_date(db,person):
-    return get_date_from_event_type(db,person,RelLib.EventType.BURIAL)
+    return get_date_from_event_type(db,person,gen.lib.EventType.BURIAL)
 
 def get_birth_date(db,person,estimate=False):
     if not person:
@@ -184,13 +196,14 @@ def get_n_children(db,person):
     for family_handle in person.get_family_handle_list():
         family = find_family(db,family_handle)
         n += len(family.get_child_ref_list())
+    return n
 
 def get_marriage_date(db,family):
     if not family:
         return 0
     for event_ref in family.get_event_ref_list():
         event = find_event(db,event_ref.ref)
-        if event.get_type() == RelLib.EventType.MARRIAGE:
+        if event.get_type() == gen.lib.EventType.MARRIAGE:
             date_obj = event.get_date_object()
             return date_obj.get_sort_value()
     return 0
@@ -217,18 +230,21 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
 
     def add_results_cli(self,results):
         # print data for the user, no GUI
-        (msg,gramps_id,name,the_type,rule_id,severity,handle) = results
+        (msg,gramps_id, name,the_type,rule_id,severity, handle) = results
         if severity == Rule.WARNING:
-            print "W: %s, %s: %s, %s" % (msg,the_type,gramps_id,name)
+            print "W: %s, %s: %s, %s" % (msg,the_type,gramps_id, name)
         elif severity == Rule.ERROR:
-            print "E: %s, %s: %s, %s" % (msg,the_type,gramps_id,name)
+            print "E: %s, %s: %s, %s" % (msg,the_type,gramps_id, name)
+        else:
+            print "S: %s, %s: %s, %s" % (msg,the_type,gramps_id, name)
 
     def init_gui(self):
         # Draw dialog and make it handle everything
         base = os.path.dirname(__file__)
         self.glade_file = base + os.sep + "verify.glade"
+        self.vr = None 
 
-        self.top = gtk.glade.XML(self.glade_file,"verify_settings","gramps")
+        self.top = glade.XML(self.glade_file,"verify_settings","gramps")
         self.top.signal_autoconnect({
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
@@ -273,14 +289,15 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                                                           
         self.show()
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (_("Tool settings"),self.label)
 
-    def on_help_clicked(self,obj):
+    def on_help_clicked(self, obj):
         """Display the relevant portion of GRAMPS manual"""
-        GrampsDisplay.help('tools-util-other')
+        GrampsDisplay.help('tools-util-other', webpage=WIKI_HELP_PAGE, 
+                                   section=WIKI_HELP_SEC)
 
-    def on_apply_clicked(self,obj):
+    def on_apply_clicked(self, obj):
         self.options.handler.options_dict['oldage'] = self.top.get_widget(
             "oldage").get_value_as_int()
         self.options.handler.options_dict['hwdif']  = self.top.get_widget(
@@ -316,15 +333,18 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                                                           self.top.get_widget(
             "estimate").get_active()
 
-        vr = VerifyResults(self.dbstate, self.uistate, self.track)
-        self.add_results = vr.add_results
-        vr.load_ignored(self.db.full_name)
-       
+        try:
+            self.vr = VerifyResults(self.dbstate, self.uistate, self.track)
+            self.add_results = self.vr.add_results
+            self.vr.load_ignored(self.db.full_name)
+        except Errors.WindowActiveError:
+            pass
+
         self.uistate.window.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
         self.uistate.progress.show()
         self.window.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
         try:
-            vr.window.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
+            self.vr.window.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.WATCH))
         except AttributeError:
             pass
 
@@ -334,7 +354,7 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
         self.uistate.window.window.set_cursor(None)
         self.window.window.set_cursor(None)
         try:
-            vr.window.window.set_cursor(None)
+            self.vr.window.window.set_cursor(None)
         except AttributeError:
             pass
         self.reset()
@@ -362,6 +382,7 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
         oldunm = self.options.handler.options_dict['oldunm']
         estimate_age = self.options.handler.options_dict['estimate_age']
 
+        self.vr.real_model.clear()
 
         self.set_total(self.db.get_number_of_people() +
                        self.db.get_number_of_families())
@@ -376,11 +397,11 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                 DeathAfterBury(self.db,person),
                 BirthAfterDeath(self.db,person),
                 BaptAfterBury(self.db,person),
-                OldAge(self.db,person,oldage,estimate_age),
+                OldAge(self.db,person, oldage,estimate_age),
                 UnknownGender(self.db,person),
                 MultipleParents(self.db,person),
                 MarriedOften(self.db,person,wedder),
-                OldUnmarried(self.db,person,oldunm,estimate_age),
+                OldUnmarried(self.db,person, oldunm,estimate_age),
                 TooManyChildren(self.db,person,mxchilddad,mxchildmom),
                 Disconnected(self.db,person),
                 ]
@@ -390,7 +411,8 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                     self.add_results(rule.report_itself())
 
             clear_cache()
-            self.update()
+            if not cli:
+                self.update()
 
         # Family-based rules
         for family_handle in self.db.get_family_handles():
@@ -401,12 +423,12 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                 FemaleHusband(self.db,family),
                 MaleWife(self.db,family),
                 SameSurnameFamily(self.db,family),
-                LargeAgeGapFamily(self.db,family,hwdif,estimate_age),
+                LargeAgeGapFamily(self.db,family, hwdif,estimate_age),
                 MarriageBeforeBirth(self.db,family,estimate_age),
                 MarriageAfterDeath(self.db,family,estimate_age),
                 EarlyMarriage(self.db,family,yngmar,estimate_age),
-                LateMarriage(self.db,family,oldmar,estimate_age),
-                OldParent(self.db,family,oldmom,olddad,estimate_age),
+                LateMarriage(self.db,family, oldmar,estimate_age),
+                OldParent(self.db,family, oldmom, olddad,estimate_age),
                 YoungParent(self.db,family,yngmom,yngdad,estimate_age),
                 UnbornParent(self.db,family,estimate_age),
                 DeadParent(self.db,family,estimate_age),
@@ -419,7 +441,8 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                     self.add_results(rule.report_itself())
                 
             clear_cache()
-            self.update()
+            if not cli:
+                self.update()
 
 #-------------------------------------------------------------------------
 #
@@ -448,7 +471,7 @@ class VerifyResults(ManagedWindow):
         base = os.path.dirname(__file__)
         self.glade_file = base + os.sep + "verify.glade"
 
-        self.top = gtk.glade.XML(self.glade_file,"verify_result","gramps")
+        self.top = glade.XML(self.glade_file,"verify_result","gramps")
         window = self.top.get_widget("verify_result")
         self.set_window(window,self.top.get_widget('title'),self.title)
     
@@ -473,8 +496,15 @@ class VerifyResults(ManagedWindow):
         self.invert_button = self.top.get_widget('invert_all')
         self.invert_button.connect('clicked',self.invert_clicked)
 
-        self.real_model = gtk.ListStore(bool,str,str,str,str,object,str,str,
-                                        bool,bool)
+        self.real_model = gtk.ListStore(gobject.TYPE_BOOLEAN, 
+                                        gobject.TYPE_STRING, 
+                                        gobject.TYPE_STRING, 
+                                        gobject.TYPE_STRING, 
+                                        gobject.TYPE_STRING, object, 
+                                        gobject.TYPE_STRING, 
+                                        gobject.TYPE_STRING,
+                                        gobject.TYPE_BOOLEAN, 
+                                        gobject.TYPE_BOOLEAN)
         self.filt_model = self.real_model.filter_new()
         self.filt_model.set_visible_column(VerifyResults.TRUE_COL)
         self.sort_model = gtk.TreeModelSort(self.filt_model)
@@ -523,7 +553,7 @@ class VerifyResults(ManagedWindow):
     def load_ignored(self,db_filename):
         md5sum = md5.md5(db_filename)
         self.ignores_filename = os.path.join(
-            const.home_dir,md5sum.hexdigest() + os.path.extsep + 'vfm')
+            const.HOME_DIR,md5sum.hexdigest() + os.path.extsep + 'vfm')
         if not self._load_ignored(self.ignores_filename):
             self.ignores = {}
 
@@ -536,7 +566,7 @@ class VerifyResults(ManagedWindow):
         except IOError:
             return False
 
-    def save_ignored(self,new_ignores):
+    def save_ignored(self, new_ignores):
         self.ignores = new_ignores
         self._save_ignored(self.ignores_filename)
 
@@ -549,7 +579,7 @@ class VerifyResults(ManagedWindow):
         except IOError:
             return False
 
-    def get_marking(self,handle,rule_id):
+    def get_marking(self, handle,rule_id):
         try:
             return (rule_id in self.ignores[handle])
         except KeyError:
@@ -622,9 +652,9 @@ class VerifyResults(ManagedWindow):
             row[VerifyResults.SHOW_COL] = not row[VerifyResults.SHOW_COL]
         self.filt_model.refilter()
 
-    def double_click(self,obj,event):
+    def double_click(self, obj,event):
         if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
-            (model,node) = self.selection.get_selected()
+            (model, node) = self.selection.get_selected()
             if not node:
                 return
             sort_path = self.sort_model.get_path(node)
@@ -656,7 +686,7 @@ class VerifyResults(ManagedWindow):
             cell.set_property('stock-id', 'gramps-family' )
 
     def add_results(self,results):
-        (msg,gramps_id,name,the_type,rule_id,severity,handle) = results
+        (msg,gramps_id, name,the_type,rule_id,severity, handle) = results
         ignore = self.get_marking(handle,rule_id)
         if severity == Rule.ERROR:
             fg = 'red'
@@ -665,15 +695,15 @@ class VerifyResults(ManagedWindow):
             #     fg = '#008b00' # green
         else:
             fg = None
-        self.real_model.append(row=[ignore,msg,gramps_id,name,
-                                    the_type,rule_id,handle,fg,
+        self.real_model.append(row=[ignore,msg,gramps_id, name,
+                                    the_type,rule_id, handle,fg,
                                     True, not ignore])
         
         if not self.window_shown:
             self.show()
             self.window_shown = True
 
-    def build_menu_names(self,obj):
+    def build_menu_names(self, obj):
         return (self.title,None)
 
 #------------------------------------------------------------------------
@@ -686,10 +716,9 @@ class VerifyOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self,name,person_id=None):
-        Tool.ToolOptions.__init__(self,name,person_id)
+    def __init__(self, name,person_id=None):
+        Tool.ToolOptions.__init__(self, name,person_id)
 
-    def set_new_options(self):
         # Options specific for this report
         self.options_dict = {
             'oldage'       : 90,
@@ -764,7 +793,7 @@ class Rule:
 
     SEVERITY = WARNING
 
-    def __init__(self,db,obj):
+    def __init__(self,db, obj):
         self.db = db
         self.obj = obj
 
@@ -804,7 +833,7 @@ class Rule:
         name = self.get_name()
         gramps_id = self.get_id()
         msg = self.get_message()
-        return (msg,gramps_id,name,the_type,rule_id,severity,handle)
+        return (msg,gramps_id, name,the_type,rule_id,severity, handle)
 
 class PersonRule(Rule):
     """
@@ -914,7 +943,7 @@ class BaptAfterBury(PersonRule):
 class OldAge(PersonRule):
     ID = 7
     SEVERITY = Rule.WARNING
-    def __init__(self,db,person,old_age,est):
+    def __init__(self,db,person, old_age,est):
         PersonRule.__init__(self,db,person)
         self.old_age = old_age
         self.est = est
@@ -933,8 +962,8 @@ class UnknownGender(PersonRule):
     ID = 8
     SEVERITY = Rule.WARNING
     def broken(self):
-        female = self.obj.get_gender() == RelLib.Person.FEMALE
-        male = self.obj.get_gender() == RelLib.Person.MALE
+        female = self.obj.get_gender() == gen.lib.Person.FEMALE
+        male = self.obj.get_gender() == gen.lib.Person.MALE
         return not (male or female)
 
     def get_message(self):
@@ -970,7 +999,7 @@ class MarriedOften(PersonRule):
 class OldUnmarried(PersonRule):
     ID = 11
     SEVERITY = Rule.WARNING
-    def __init__(self,db,person,old_unm,est):
+    def __init__(self,db,person, old_unm,est):
         PersonRule.__init__(self,db,person)
         self.old_unm = old_unm
         self.est = est
@@ -989,8 +1018,8 @@ class OldUnmarried(PersonRule):
 class TooManyChildren(PersonRule):
     ID = 12
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,mx_child_dad,mx_child_mom):
-        PersonRule.__init__(self,db,obj)
+    def __init__(self,db, obj,mx_child_dad,mx_child_mom):
+        PersonRule.__init__(self,db, obj)
         self.mx_child_dad = mx_child_dad
         self.mx_child_mom = mx_child_mom
 
@@ -1000,11 +1029,11 @@ class TooManyChildren(PersonRule):
     def broken(self):
         n_child = get_n_children(self.db,self.obj)
 
-        if (self.obj.get_gender == RelLib.Person.MALE) \
+        if (self.obj.get_gender == gen.lib.Person.MALE) \
                and (n_child > self.mx_child_dad):
             return True
 
-        if (self.obj.get_gender == RelLib.Person.FEMALE) \
+        if (self.obj.get_gender == gen.lib.Person.FEMALE) \
                and (n_child > self.mx_child_mom):
             return True
 
@@ -1022,7 +1051,7 @@ class SameSexFamily(FamilyRule):
         same_sex = (mother and father and
                     (mother.get_gender() == father.get_gender()))
         unknown_sex = (mother and
-                       (mother.get_gender() == RelLib.Person.UNKNOWN))
+                       (mother.get_gender() == gen.lib.Person.UNKNOWN))
         return (same_sex and not unknown_sex)
 
     def get_message(self):
@@ -1033,7 +1062,7 @@ class FemaleHusband(FamilyRule):
     SEVERITY = Rule.WARNING
     def broken(self):
         father = get_father(self.db,self.obj)
-        return (father and (father.get_gender() == RelLib.Person.FEMALE))
+        return (father and (father.get_gender() == gen.lib.Person.FEMALE))
 
     def get_message(self):
         return _("Female husband")
@@ -1043,7 +1072,7 @@ class MaleWife(FamilyRule):
     SEVERITY = Rule.WARNING
     def broken(self):
         mother = get_mother(self.db,self.obj)
-        return (mother and (mother.get_gender() == RelLib.Person.MALE))
+        return (mother and (mother.get_gender() == gen.lib.Person.MALE))
 
     def get_message(self):
         return _("Male wife")
@@ -1052,14 +1081,25 @@ class SameSurnameFamily(FamilyRule):
     ID = 16
     SEVERITY = Rule.WARNING
     def broken(self):
-        mother = get_mother(self.db,self.obj)
-        father = get_father(self.db,self.obj)
-        same_surname = (father and mother and
-                        (mother.get_primary_name().get_surname() ==
-                         father.get_primary_name().get_surname()))
-        empty_surname = mother and \
-                        (len(mother.get_primary_name().get_surname())==0)
-        return (same_surname and not empty_surname)
+        mother = get_mother(self.db, self.obj)
+        father = get_father(self.db, self.obj)
+        _broken = False
+        
+        # Make sure both mother and father exist.
+        if mother and father:
+            mname = mother.get_primary_name()
+            fname = father.get_primary_name()
+            # Only compare birth names (not married names).
+            if mname.get_type() == gen.lib.NameType.BIRTH and \
+               fname.get_type() == gen.lib.NameType.BIRTH:
+                # Empty names don't count.
+                if len(mname.get_surname()) != 0 and \
+                   len(fname.get_surname()) != 0:
+                    # Finally, check if the names are the same.
+                    if mname.get_surname() == fname.get_surname():
+                        _broken = True
+
+        return _broken
 
     def get_message(self):
         return _("Husband and wife with the same surname")
@@ -1067,8 +1107,8 @@ class SameSurnameFamily(FamilyRule):
 class LargeAgeGapFamily(FamilyRule):
     ID = 17
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,hw_diff,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj, hw_diff,est):
+        FamilyRule.__init__(self,db, obj)
         self.hw_diff = hw_diff
         self.est = est
 
@@ -1092,8 +1132,8 @@ class LargeAgeGapFamily(FamilyRule):
 class MarriageBeforeBirth(FamilyRule):
     ID = 18
     SEVERITY = Rule.ERROR
-    def __init__(self,db,obj,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,est):
+        FamilyRule.__init__(self,db, obj)
         self.est = est
 
     def _get_params(self):
@@ -1123,8 +1163,8 @@ class MarriageBeforeBirth(FamilyRule):
 class MarriageAfterDeath(FamilyRule):
     ID = 19
     SEVERITY = Rule.ERROR
-    def __init__(self,db,obj,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,est):
+        FamilyRule.__init__(self,db, obj)
         self.est = est
 
     def _get_params(self):
@@ -1154,8 +1194,8 @@ class MarriageAfterDeath(FamilyRule):
 class EarlyMarriage(FamilyRule):
     ID = 20
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,yng_mar,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,yng_mar,est):
+        FamilyRule.__init__(self,db, obj)
         self.yng_mar = yng_mar
         self.est = est
 
@@ -1174,8 +1214,10 @@ class EarlyMarriage(FamilyRule):
         father_birth_date_ok = father_birth_date > 0
 
         father_broken = (father_birth_date_ok and marr_date_ok and
+                         father_birth_date < marr_date and
                          ((marr_date - father_birth_date)/365 < self.yng_mar))
         mother_broken = (mother_birth_date_ok and marr_date_ok and
+                         mother_birth_date < marr_date and
                          ((marr_date - mother_birth_date)/365 < self.yng_mar))
 
         return (father_broken or mother_broken)
@@ -1186,8 +1228,8 @@ class EarlyMarriage(FamilyRule):
 class LateMarriage(FamilyRule):
     ID = 21
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,old_mar,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj, old_mar,est):
+        FamilyRule.__init__(self,db, obj)
         self.old_mar = old_mar
         self.est = est
 
@@ -1237,8 +1279,8 @@ class LateMarriage(FamilyRule):
 class OldParent(FamilyRule):
     ID = 22
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,old_mom,old_dad,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj, old_mom, old_dad,est):
+        FamilyRule.__init__(self,db, obj)
         self.old_mom = old_mom
         self.old_dad = old_dad
         self.est = est
@@ -1282,8 +1324,8 @@ class OldParent(FamilyRule):
 class YoungParent(FamilyRule):
     ID = 23
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,yng_mom,yng_dad,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,yng_mom,yng_dad,est):
+        FamilyRule.__init__(self,db, obj)
         self.yng_dad = yng_dad
         self.yng_mom = yng_mom
         self.est = est
@@ -1327,8 +1369,8 @@ class YoungParent(FamilyRule):
 class UnbornParent(FamilyRule):
     ID = 24
     SEVERITY = Rule.ERROR
-    def __init__(self,db,obj,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,est):
+        FamilyRule.__init__(self,db, obj)
         self.est = est
 
     def _get_params(self):
@@ -1369,8 +1411,8 @@ class UnbornParent(FamilyRule):
 class DeadParent(FamilyRule):
     ID = 25
     SEVERITY = Rule.ERROR
-    def __init__(self,db,obj,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,est):
+        FamilyRule.__init__(self,db, obj)
         self.est = est
 
     def _get_params(self):
@@ -1390,13 +1432,19 @@ class DeadParent(FamilyRule):
             child_birth_date_ok = child_birth_date > 0
             if not child_birth_date_ok:
                 continue
-            father_broken = (father_death_date_ok
-                             and (father_death_date < child_birth_date))
+
+            hasBirthRelToMother = child_ref.mrel == gen.lib.ChildRefType.BIRTH    
+            hasBirthRelToFather = child_ref.frel == gen.lib.ChildRefType.BIRTH
+            
+            father_broken = (hasBirthRelToFather
+                             and father_death_date_ok
+                             and ((father_death_date + 294) < child_birth_date))
             if father_broken:
                 self.get_message = self.father_message
                 return True
 
-            mother_broken = (mother_death_date_ok
+            mother_broken = (hasBirthRelToMother
+                             and mother_death_date_ok
                              and (mother_death_date < child_birth_date))
             if mother_broken:
                 self.get_message = self.mother_message
@@ -1411,8 +1459,8 @@ class DeadParent(FamilyRule):
 class LargeChildrenSpan(FamilyRule):
     ID = 26
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,cb_span,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,cb_span,est):
+        FamilyRule.__init__(self,db, obj)
         self.cb_span = cb_span
         self.est = est
 
@@ -1433,8 +1481,8 @@ class LargeChildrenSpan(FamilyRule):
 class LargeChildrenAgeDiff(FamilyRule):
     ID = 27
     SEVERITY = Rule.WARNING
-    def __init__(self,db,obj,c_space,est):
-        FamilyRule.__init__(self,db,obj)
+    def __init__(self,db, obj,c_space,est):
+        FamilyRule.__init__(self,db, obj)
         self.c_space = c_space
         self.est = est
 
@@ -1473,7 +1521,9 @@ register_tool(
     tool_class = Verify,
     options_class = VerifyOptions,
     modes = Tool.MODE_GUI | Tool.MODE_CLI,
-    translated_name = _("Verify the database"),
-    description = _("Lists exceptions to assertions or checks "
-                    "about the database")
+    translated_name = _("Verify the Data"),
+    status=(_("Stable")),
+    author_name = "Alex Roitman",
+    author_email = "shura@gramps-project.org",
+    description = _("Verifies the data against user-defined tests")
     )
